# Authors
SharePoint Too is written and maintained by Tim Santor and various contributors:

## Development Lead
- Tim Santor <tsantor@xstudios.agency>

## Contributors
None yet. Why not be the first?
